<?php
	
	class onAuthplusUserAuthError extends cmsAction {
		
		public function run($data){
			
			// Если включены авторизация по альтернативным полям и авторизация по API - переходим к ним
			if (!empty($this->options['is_alter']) || !empty($this->options['is_api'])){
				
				// Получаем список полей, по которым будем пытаться авторизоваться
				$alter_columns = $this->options['alter_columns'];
				
				return $this->getUserByAuth($data['email'], $data['password'], $alter_columns);
			}
			
		}
		
	    public function getUserByAuth($email, $password, $alter_columns) {
			
			// Нет пароля или еще чего - сразу на выход
			if(!$password || !$email || !$alter_columns){ return false; }
			
			// Отсеиваем удаленных пользователей
			$this->model_users->filterIsNull('is_deleted');
			
			// Получаем пользователя по заданным полям
			$user = $this->getUserByAlter($email, $alter_columns);
			
			// совместимость с ранее захэшированными паролями
			// ищем юзера по email, если есть,
			// проверяем по двум алгоритмам
			if($user){
				
				// старый механизм
				if(empty($user['password_hash'])){
					
					$password_hash = md5(md5($password) . $user['password_salt']);
					
					if ($password_hash !== $user['password']){
						$user = false;
						} else {
						// ставим метку в массив, что старая авторизация
						$user['is_old_auth'] = true;
					}
					
					// новый механизм
					} else {
					
					if (!password_verify($password, $user['password_hash'])) {
						$user = false;
					}
					
				}
				
			}
			
			// Если не удалось авторизоваться по альтернативным полям и если включена авторизация по API - пытаемся авторизоваться по API
			if (!$user && !empty($this->options['is_api'])){
				
				// Получаем ответ от удаленного сайта
				$response = json_decode(file_get_contents($this->options['api_site'].'/api/method/users.get_sig?api_key='.$this->options['api_key']), true);
				
				// Есть ответ - раскодируем его. Нет ответа - выдаем фальс
				$json = !empty($response['response']) ? file_get_contents($this->options['api_site'].'/api/method/auth.login?api_key='.$this->options['api_key'].'&sig='.$response['response']['sig'].'&email='.$email.'&password='.$password) : false;
				
				// Нет ответа от удаленного сервера или ошибка авторизации - выходим
				if (empty($json) || strpos($json, 'error') !== false){return false;}
				
				// Получаем данные пользователя с удаленного сайта
				$user = json_decode($json, true)['response']['user_info'];
				
				// Айди у нового пользователя будет новый
				$user['id'] = false;
				
				// И админы таким образом не станут заходить
				$user['is_admin'] = NULL;
				
				// Пароль нового пользователя
				$user['password1'] = $user['password2'] = $password;
				
				// Добавляем нового пользователя
				$new_user = $this->model_users->addUser($user);
				
				// Получаем id нового пользователя
				$user['id'] = $new_user['id'];
				
				// Получаем объект нового пользователя и далее работаем с ним.
				cmsUser::getInstance()->id = $user['id'];
				
				$avatar_options = $this->model_users->yamlToArray($this->model_users->db->getRow('users_fields', 'name = "avatar"')['options']);
				
				// Задаем пресеты, в которые будет сохраняться аватар нового пользователя
				$this->request->set('sizes', implode($avatar_options['sizes']));
				
				// Если у удаленного пользователя есть аватар и он имеет пресет normal - загружаем аватар себе на сайт
				if (!empty($user['avatar']['normal']) && strpos($user['avatar']['normal'], 'upload') !== false){
				
				$_POST['avatar'] = $user['avatar']['normal'];
				
				foreach ($avatar_options['sizes'] as $size){
					
					$ava = $this->controller_images->uploadWithPreset('avatar', $size);
					
					$avatars[$size] = $ava['image']['path'];
					
				}
				
				$user['avatar'] = $this->model_users->arrayToYaml($avatars);
				
				} else {$user['avatar'] = null;}
				
				// Обновляем профиль нового пользователя
				$this->model_users->updateUser($user['id'], $user);
				
			}
			
			return $user;
			
		}
		
		public function getUserByAlter($email, $alter_columns){
			
			if(!$email){ return false; }
			
			foreach ($alter_columns as $ac){
				
				$us = $this->model_users->filterEqual($ac, $email, true)->getUser();
				
				if ($us){return $us;} else {continue;}
				
			}
			
		}
		
	}
